@@ -19,7 +19,7 @@ def run():
     admin.execute()
 
     if not __testing__:
-        with GameBotClient('bot', host=host, port=port) as bot:
+        with GameBotClient('bot') as bot:
             while True:
                 response = bot.send("ping")
                 data = response.decode()
